HlsParamsUnchecked

Type Alias HlsParamsUnchecked 

pub type HlsParamsUnchecked = HlsParamsBase<String>;

Aliased Type

pub struct HlsParamsUnchecked {
    pub max_loan_to_value: Decimal,
    pub liquidation_threshold: Decimal,
    pub correlations: Vec<HlsAssetType<String>>,
}

Fields

max_loan_to_value: Decimalliquidation_threshold: Decimalcorrelations: Vec<HlsAssetType<String>>

Given this asset is debt, correlations are the only allowed collateral which are permitted to fulfill the HLS strategy

Implementations