Struct mars_params::types::AssetParamsResponse
source · pub struct AssetParamsResponse {
pub denom: String,
pub params: AssetParams,
}Fields
denom: Stringparams: AssetParamsTrait Implementations
sourceimpl Clone for AssetParamsResponse
impl Clone for AssetParamsResponse
sourcefn clone(&self) -> AssetParamsResponse
fn clone(&self) -> AssetParamsResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AssetParamsResponse
impl Debug for AssetParamsResponse
sourceimpl<'de> Deserialize<'de> for AssetParamsResponse
impl<'de> Deserialize<'de> for AssetParamsResponse
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for AssetParamsResponse
impl JsonSchema for AssetParamsResponse
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<AssetParamsResponse> for AssetParamsResponse
impl PartialEq<AssetParamsResponse> for AssetParamsResponse
sourcefn eq(&self, other: &AssetParamsResponse) -> bool
fn eq(&self, other: &AssetParamsResponse) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for AssetParamsResponse
impl Serialize for AssetParamsResponse
impl StructuralPartialEq for AssetParamsResponse