Struct mars_params::types::AssetPermissions
source · pub struct AssetPermissions {
pub rover: RoverPermissions,
pub red_bank: RedBankSettings,
}Fields
rover: RoverPermissionsred_bank: RedBankSettingsTrait Implementations
sourceimpl Clone for AssetPermissions
impl Clone for AssetPermissions
sourcefn clone(&self) -> AssetPermissions
fn clone(&self) -> AssetPermissions
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AssetPermissions
impl Debug for AssetPermissions
sourceimpl<'de> Deserialize<'de> for AssetPermissions
impl<'de> Deserialize<'de> for AssetPermissions
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for AssetPermissions
impl JsonSchema for AssetPermissions
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<AssetPermissions> for AssetPermissions
impl PartialEq<AssetPermissions> for AssetPermissions
sourcefn eq(&self, other: &AssetPermissions) -> bool
fn eq(&self, other: &AssetPermissions) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for AssetPermissions
impl Serialize for AssetPermissions
impl StructuralPartialEq for AssetPermissions