Struct mars_params::types::RedBankSettings
source · pub struct RedBankSettings {
pub deposit_enabled: bool,
pub borrow_enabled: bool,
pub deposit_cap: Uint128,
}Fields
deposit_enabled: boolborrow_enabled: booldeposit_cap: Uint128Trait Implementations
sourceimpl Clone for RedBankSettings
impl Clone for RedBankSettings
sourcefn clone(&self) -> RedBankSettings
fn clone(&self) -> RedBankSettings
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RedBankSettings
impl Debug for RedBankSettings
sourceimpl<'de> Deserialize<'de> for RedBankSettings
impl<'de> Deserialize<'de> for RedBankSettings
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for RedBankSettings
impl JsonSchema for RedBankSettings
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<RedBankSettings> for RedBankSettings
impl PartialEq<RedBankSettings> for RedBankSettings
sourcefn eq(&self, other: &RedBankSettings) -> bool
fn eq(&self, other: &RedBankSettings) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for RedBankSettings
impl Serialize for RedBankSettings
impl StructuralPartialEq for RedBankSettings