Struct mars_params::types::RoverPermissions
source · pub struct RoverPermissions {
pub whitelisted: bool,
}Fields
whitelisted: boolTrait Implementations
sourceimpl Clone for RoverPermissions
impl Clone for RoverPermissions
sourcefn clone(&self) -> RoverPermissions
fn clone(&self) -> RoverPermissions
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RoverPermissions
impl Debug for RoverPermissions
sourceimpl<'de> Deserialize<'de> for RoverPermissions
impl<'de> Deserialize<'de> for RoverPermissions
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for RoverPermissions
impl JsonSchema for RoverPermissions
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<RoverPermissions> for RoverPermissions
impl PartialEq<RoverPermissions> for RoverPermissions
sourcefn eq(&self, other: &RoverPermissions) -> bool
fn eq(&self, other: &RoverPermissions) -> bool
This method tests for
self and other values to be equal, and is used
by ==.