Struct mars_params::types::RoverSettings
source · pub struct RoverSettings {
pub whitelisted: bool,
pub hls: HighLeverageStrategyParams,
}Fields
whitelisted: boolhls: HighLeverageStrategyParamsTrait Implementations
sourceimpl Clone for RoverSettings
impl Clone for RoverSettings
sourcefn clone(&self) -> RoverSettings
fn clone(&self) -> RoverSettings
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RoverSettings
impl Debug for RoverSettings
sourceimpl<'de> Deserialize<'de> for RoverSettings
impl<'de> Deserialize<'de> for RoverSettings
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for RoverSettings
impl JsonSchema for RoverSettings
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq<RoverSettings> for RoverSettings
impl PartialEq<RoverSettings> for RoverSettings
sourcefn eq(&self, other: &RoverSettings) -> bool
fn eq(&self, other: &RoverSettings) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for RoverSettings
impl Serialize for RoverSettings
impl StructuralPartialEq for RoverSettings