pub struct LiquidationBonus {
pub starting_lb: Decimal,
pub slope: Decimal,
pub min_lb: Decimal,
pub max_lb: Decimal,
}Expand description
The LB will depend on the Health Factor and a couple other parameters as follows: Liquidation Bonus = min( b + (slope * (1 - HF)), max( min(CR - 1, max_lb), min_lb ) )
Fields
starting_lb: DecimalMarks the level at which the LB starts when HF drops marginally below 1. If set at 1%, at HF = 0.999 the LB will be 1%. If set at 0%, the LB starts increasing from 0% as the HF drops below 1.
slope: DecimalDefines the slope at which the LB increases as the HF decreases. The higher the slope, the faster the LB increases as the HF decreases.
min_lb: DecimalMinimum LB that will be granted to liquidators even when the position is undercollateralized.
max_lb: DecimalMaximum LB that can be granted to a liquidator; in other words, the maxLB establishes a ceiling to the LB. This is a precautionary parameter to mitigate liquidated users being over-punished.
Implementations
Sourceimpl LiquidationBonus
impl LiquidationBonus
pub fn validate(&self) -> Result<(), ValidationError>