pub type HlsParams = HlsParamsBase<Addr>;Aliased Type
pub struct HlsParams {
pub max_loan_to_value: Decimal,
pub liquidation_threshold: Decimal,
pub correlations: Vec<HlsAssetType<Addr>>,
}Fields
max_loan_to_value: Decimalliquidation_threshold: Decimalcorrelations: Vec<HlsAssetType<Addr>>Given this asset is debt, correlations are the only allowed collateral which are permitted to fulfill the HLS strategy